# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .alias import *
from .deployment import *
from .dns_record import *
from .get_alias import *
from .get_file import *
from .get_prebuilt_project import *
from .get_project import *
from .get_project_directory import *
from .project import *
from .project_domain import *
from .project_environment_variable import *
from .provider import *
from .shared_environment_variable import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumiverse_vercel.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumiverse_vercel.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "vercel",
  "mod": "index/alias",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/alias:Alias": "Alias"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/deployment",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/dnsRecord",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/dnsRecord:DnsRecord": "DnsRecord"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/project",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/project:Project": "Project"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectDomain",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectDomain:ProjectDomain": "ProjectDomain"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectEnvironmentVariable",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectEnvironmentVariable:ProjectEnvironmentVariable": "ProjectEnvironmentVariable"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/sharedEnvironmentVariable",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/sharedEnvironmentVariable:SharedEnvironmentVariable": "SharedEnvironmentVariable"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "vercel",
  "token": "pulumi:providers:vercel",
  "fqn": "pulumiverse_vercel",
  "class": "Provider"
 }
]
"""
)
